@@ -16,6 +16,7 @@ $lang['cancel'] = 'Annuler';
 $lang['category_template'] = 'Gabarit : vue de cat&eacute;gorie';
 $lang['center_lat'] = 'Latitude du centre ';
 $lang['center_lon'] = 'Longitude du centre ';
+$lang['clearcache'] = 'Effacer le cache de g&eacute;olocalisation';
 $lang['click'] = 'Clic';
 $lang['combine_points'] = 'Grouper les points selon leur proximit&eacute; ';
 $lang['combined_points_icon'] = 'Ic&ocirc;ne &agrave; utiliser pour les groupes de points ';
@@ -220,6 +221,7 @@ $lang['map_type'] = 'Type de carte ';
 $lang['metric'] = 'M&eacute;trique';
 $lang['moddescription'] = 'Un module complet pour cr&eacute;er des cartes avec Google Maps ou Yahoo Maps. Cr&eacute;ation de cartes, ajout de points, tri par cat&eacute;gories, points dynamiques, etc.';
 $lang['mouseover'] = 'Survol de la souris';
+$lang['msg_addresscache_cleared'] = 'Cache de g&eacute;olocalisation effac&eacute;';
 $lang['msg_categoryadded'] = 'Cat&eacute;gorie ajout&eacute;e';
 $lang['msg_categorydeleted'] = 'Cat&eacute;gorie supprim&eacute;e';
 $lang['msg_categoryupdated'] = 'Cat&eacute;gorie mise &agrave; jour';
@@ -283,8 +285,9 @@ $lang['use_marker_icon'] = 'Pr&eacute;f&eacute;rer l&#039;ic&ocirc;ne du point';
 $lang['width'] = 'Largeur ';
 $lang['window'] = 'Fen&ecirc;tre';
 $lang['zoom_encompass'] = 'Entourage du zoom ';
-$lang['utmz'] = '156861353.1317639646.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
-$lang['utma'] = '156861353.1126794490.1317639646.1317639646.1317714526.2';
+$lang['qca'] = 'P0-571252815-1315078016297';
+$lang['utma'] = '156861353.179240496.1322590189.1322590189.1322599553.2';
 $lang['utmc'] = '156861353';
-$lang['utmb'] = '156861353';
+$lang['utmz'] = '156861353.1322590189.1.1.utmcsr=(direct)|utmccn=(direct)|utmcmd=(none)';
+$lang['utmb'] = '156861353.1.10.1322599553';
 ?>
\ No newline at end of file
