@@ -8,7 +8,7 @@ $lang['add_point_for_map'] = 'Legg punkt til kart &quot;%s&quot;';
 $lang['aerial'] = 'Flyfoto';
 $lang['anchor_x'] = 'Anker X pixel lokasjon';
 $lang['anchor_y'] = 'Anker Y pixel lokasjon';
-$lang['apply'] = 'Utf&oslash;r';
+$lang['apply'] = 'Bruk';
 $lang['ask_delete_icon'] = 'Er du sikker p&aring; at vil fjerne dette ikonet fra listen (ingen filer vil bli slettet)';
 $lang['ask_reset_icons'] = 'Er du sikker p&aring; at du vil fjerne alle ikoner, og tilbakestille til fabrikkstandard?';
 $lang['baloon_maptemplate'] = 'Boble mal';
@@ -16,6 +16,7 @@ $lang['cancel'] = 'Avbryt';
 $lang['category_template'] = 'Kategori visningsmal';
 $lang['center_lat'] = 'Sentrer Breddegrad(Latitude)';
 $lang['center_lon'] = 'Sentrer Lengdegrad(Longitude)';
+$lang['clearcache'] = 'T&oslash;m det geografiske lokasjonsmellomlageret';
 $lang['click'] = 'Klikk';
 $lang['combine_points'] = 'Kombiner individuelle mark&oslash;rer som er innenfor rekkevidde';
 $lang['combined_points_icon'] = 'Ikon &aring; benytte for kombinerte mark&oslash;rer';
@@ -148,6 +149,8 @@ $lang['help_icon_url'] = 'Spesifiser URLen til det for-opplastede PNG-bildet. De
 $lang['help_param_defer'] = 'Angi at alle JavaScript-taggene skal ha utsette attributtsett. Dette kan v&aelig;re nyttig for problemer med IE7 og IE8 der Internet Explorer pr&oslash;ver &aring; kj&oslash;re javascript p&aring; en ufullstendig gjengitt side.';
 $lang['help_param_map'] = 'Spesifiser IDen eller kartets navn som skal benyttes for &aring; legge ut google kartet. Om denne parameter ikke er spesifisert vil standard kart (om noe) bli benyttet.';
 $lang['help_param_maptemplate'] = 'Spesifiser navnet p&aring; en eksisterende, ikke standard kartmal som skal benyttes for denne visningen. Om denne parameter ikke er spesifisert, vil n&aring;v&aelig;rende standard mal bli benyttet';
+$lang['help_param_zoomlevel'] = '(integer) Tillater overstyring av zoom-niv&aring; lagret med kartet. Gyldige verdier er fra 1 til 17';
+$lang['help_param_zoomencompass'] = '(boolean) Tillater overstyring av zoom omfang innstillingen som er lagret med kartet.';
 $lang['hide_directions'] = 'Skjul kj&oslash;rerute';
 $lang['horizontal_bar'] = 'Horisontal linjal';
 $lang['hybrid'] = 'Hybrid ';
@@ -218,6 +221,7 @@ $lang['map_type'] = 'Karttype';
 $lang['metric'] = 'Metrisk';
 $lang['moddescription'] = 'En enkel modul for &aring; lage google kart';
 $lang['mouseover'] = 'MouseOver ';
+$lang['msg_addresscache_cleared'] = 'Geografisk lokasjonslager t&oslash;mt';
 $lang['msg_categoryadded'] = 'Kategori lagt til';
 $lang['msg_categorydeleted'] = 'Kategori slettet';
 $lang['msg_categoryupdated'] = 'Kategori oppdatert';
@@ -262,7 +266,7 @@ $lang['show_category_panel'] = 'Vis kategoripanelet';
 $lang['sidebar'] = 'Vis sidestolpe';
 $lang['sidebar_template'] = 'Sidestolpe mal';
 $lang['small'] = 'Liten';
-$lang['submit'] = 'Utf&oslash;r';
+$lang['submit'] = 'Lagre';
 $lang['sv_controls'] = 'Vis gatevisningskontroller';
 $lang['sv_radius'] = 'Streetview s&oslash;keradius';
 $lang['tab_advanced'] = 'Avansert';
@@ -281,9 +285,9 @@ $lang['use_marker_icon'] = 'Foretrekk mark&oslash;rikonet';
 $lang['width'] = 'Bredde';
 $lang['window'] = 'Vindu';
 $lang['zoom_encompass'] = 'Zoom tilpasset';
-$lang['utmz'] = '156861353.1292071197.3458.79.utmcsr=forum.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/index.php/topic,49989.0/topicseen.html';
-$lang['utma'] = '156861353.179052623084110100.1210423577.1295909416.1295985955.3518';
-$lang['qca'] = '1210971690-27308073-81952832';
-$lang['utmb'] = '156861353.2.10.1295985955';
+$lang['qca'] = 'P0-536849115-1307983495210';
+$lang['utma'] = '156861353.1633959484.1322167008.1322178860.1322242091.3';
+$lang['utmz'] = '156861353.1322167008.1.1.utmcsr=(direct)|utmccn=(direct)|utmcmd=(none)';
 $lang['utmc'] = '156861353';
+$lang['utmb'] = '156861353.1.10.1322242091';
 ?>
\ No newline at end of file
