@@ -301,8 +301,8 @@ class cggm_map_generator
 	$tmp = '<div class="cggm_marker" id="map_'.self::$_instance.'_marker_'.$marker_name.'">'."\n";
 	$tmp .= '<input type="hidden" name="name" value="'.$marker_name.'"/>'."\n";
 	$tmp .= '<input type="hidden" name="title" value="'.cms_htmlentities($marker->get_title()).'"/>'."\n";
-	$tmp .= '<input type="hidden" name="latitude" value="'.number_format($marker->get_latitude(),'.','');.'"/>'."\n";
-	$tmp .= '<input type="hidden" name="longitude" value="'.number_format($marker->get_longitude(),'.','').'"/>'."\n";
+	$tmp .= '<input type="hidden" name="latitude" value="'.number_format($marker->get_latitude(),6,'.','').'"/>'."\n";
+	$tmp .= '<input type="hidden" name="longitude" value="'.number_format($marker->get_longitude(),6,'.','').'"/>'."\n";
 	$tmp .= '<input type="hidden" name="icon" value="'.$marker->get_icon().'"/>'."\n";
 	$tmp .= '<input type="hidden" name="categories" value="'.$marker->get_categories().'"/>'."\n";
 
